import { writeFileSync } from 'fs';
import { configuration } from './config.js';
import { loadJsonFile } from './load-json-file.js';
;
export class DebugKeyboard {
    id;
    filename;
    sha256;
    lastUse;
    path;
    version;
    oskFontFace;
    fontFace;
    filenameFromId(id) {
        return id + '.js';
    }
    toRegistrationBlob() {
        let o = {
            KN: this.id,
            KI: 'Keyboard_' + this.id,
            KL: this.id,
            KLC: 'en',
            KR: 'Europe',
            KRC: 'eu',
            KFont: this.fontFace ? { family: this.fontFace } : undefined,
            KOskFont: this.oskFontFace ? { family: this.oskFontFace } : undefined,
            KF: this.id + '.js'
        };
        return JSON.stringify(o, null, 2) + '/*' + this.sha256 + '*/';
    }
    ;
}
;
export class DebugModel {
    id;
    filename;
    sha256;
    lastUse;
    filenameFromId(id) {
        return id + '.model.js';
    }
    toRegistrationBlob() {
        return JSON.stringify(this.id) + ', ' + JSON.stringify(this.id + '.model.js') + '/*' + this.sha256 + '*/';
    }
}
;
export class DebugPackage {
    id;
    filename;
    sha256;
    lastUse;
    name;
    filenameFromId(id) {
        return id + '.kmp';
    }
}
;
export class DebugFont {
    id;
    filename;
    sha256;
    lastUse;
    facename;
    filenameFromId(id) {
        return simplifyId(id) + '.ttf';
    }
}
;
export class SiteData {
    keyboards = {};
    models = {};
    packages = {};
    fonts = {};
    constructor() {
        this.loadState();
    }
    loadDebugObject(type, source, dest) {
        for (let id in source) {
            dest[id] = Object.assign(new type(), source[id]);
        }
    }
    loadState() {
        const state = loadJsonFile(configuration.cacheStateFilename);
        this.loadDebugObject(DebugKeyboard, state?.keyboards, this.keyboards);
        this.loadDebugObject(DebugModel, state?.models, this.models);
        this.loadDebugObject(DebugFont, state?.fonts, this.fonts);
        this.loadDebugObject(DebugPackage, state?.packages, this.packages);
        // todo cleanup of missing files
    }
    saveState() {
        writeFileSync(configuration.cacheStateFilename, JSON.stringify(this, null, 2), 'utf-8');
    }
}
;
export let data = new SiteData();
export function isValidId(id) {
    return !id.match(/\.\.|\/|\\/);
}
export function simplifyId(id) {
    return id.replace(/[^_a-zA-Z0-9-]/g, '_');
}
//# sourceMappingURL=data.js.map