import * as os from 'os';
import * as fs from 'fs';
import * as path from 'path';
;
// Default has no options set, and unit tests will use the defaults (won't call
// `loadOptions()`)
let options = {};
// We only load the options from disk once on first use
let optionsLoaded = false;
export async function loadOptions() {
    if (optionsLoaded) {
        return options;
    }
    options = {};
    try {
        const optionsFile = path.join(os.homedir(), '.keymandeveloper', 'options.json');
        if (fs.existsSync(optionsFile)) {
            for (let i = 0; i < 5; i++) {
                try {
                    const data = JSON.parse(fs.readFileSync(optionsFile, 'utf-8'));
                    if (typeof data == 'object') {
                        options = data;
                    }
                    break;
                }
                catch (e) {
                    if (e?.code == 'EBUSY') {
                        await new Promise(resolve => setTimeout(resolve, 500));
                    }
                    else {
                        // give up, nothing to report here
                        break;
                    }
                }
            }
        }
    }
    catch (e) {
        // Nothing to report here, sadly -- because we cannot rely on Sentry at this
        // low level.
        options = {};
    }
    optionsLoaded = true;
    return options;
}
export function getOption(valueName, defaultValue) {
    return options[valueName] ?? defaultValue;
}
/**
 * unit tests will clear options before running, for consistency
 */
export function clearOptions() {
    options = {};
    optionsLoaded = true;
}
//# sourceMappingURL=options.js.map